==> aleksis_core-4.0.0.dev12-py3-none-any.whl: aleksis/core/frontend/mixins/mutateMixin.js <==
import loadingMixin from "./loadingMixin.js";

/**
 * This mixin provides generic graphQL mutation handling.
 */
export default {
  mixins: [loadingMixin],
  props: {
    /**
     * The graphQL query this mutation affects.
     * If provided the cached query will be updated.
     * Either use lastQuery from the queryMixin or
     * $apollo.queries[lastQueryName].
     */
    affectedQuery: {
      type: Object,
      required: false,
      default: null,
    },
    /**
     * Key of the affected query data
     * Key can be a single key or nested keys seperated by a '.'
     */
    gqlDataKey: {
      type: String,
      required: false,
      default: "items",
    },
    // itemId is unused in mutateMixin but shared by both
    // createOrPatchMixin & deleteMixin
    /**
     * The item's id property.
     */
    itemId: {
      type: String,
      required: false,
      default: "id",
    },
    /**
     * Method to perform a custom update.
     *
     * This is an alternative way of supplying this method.
     * In case a method is set here, it has higher priority
     * than the one directly submitted to the mutate function.
     */
    customUpdate: {
      type: Function,
      required: false,
      default: undefined,
    },
  },
  // update & save come from DialogObjectForm
  // save could be success as well but keeping it backwards compatible
  // for now
  emits: ["update", "save"],
  computed: {
    // Expand the affectedQuery
    expandedQuery() {
      if (!this.affectedQuery) {
        return false;
      }
      return {
        ...this.affectedQuery.options,
        variables: JSON.parse(this.affectedQuery.previousVariablesJson),
      };
    },
  },
  methods: {
    /**
     * Do a graphQL mutation with variables
     *
     * Provide updateStore to update the cached data for affectedQuery with
     * the incoming data.
     *
     * @param {Object} mutation
     * @param {Object} variables
     * @param {Function} updateStore
     * @param {Object} additionalArgs additional arguments passed to apollo mutate function options
     */
    mutate(
      mutation,
      variables,
      updateStore = (cached, incoming) => {},
      additionalArgs = {},
    ) {
      this.handleLoading(true);

      if (this.customUpdate) {
        updateStore = this.customUpdate;
      }

      this.$apollo
        .mutate({
          mutation: mutation,
          variables: variables,
          update: (store, data) => {
            // TODO: Is data transformed properly?
            // Current implemented for create | patch
            // What does it return for delete?
            data = data.data[mutation.definitions[0].name.value].items;

            // Update cached data
            if (this.expandedQuery) {
              // Read the data from cache for query
              const cachedQuery = store.readQuery(this.expandedQuery);
              if (cachedQuery) {
                // Update the store
                this.setKeysRecursive(
                  this.gqlDataKey,
                  cachedQuery,
                  updateStore(
                    this.getKeysRecursive(this.gqlDataKey, cachedQuery),
                    data,
                  ),
                );
                // Write data back to the cache
                store.writeQuery({ ...this.expandedQuery, data: cachedQuery });
              }
            }

            /**
             * Emits the store and data when graphQL updates
             * Use this to update the cached query if  affectedQuery or
             * updateStore was not provided
             *
             * @property {object} store
             * @property {object} updated object
             */
            this.$emit("update", store, data);
          },
          ...additionalArgs,
        })
        .then((data) => {
          /**
           * Emits the items of a successful graphQL mutation
           * If affectedQuery was provided the items are already updated in the cache.
           *
           * @property {object} data
           */
          this.$emit(
            "save",
            data.data[mutation.definitions[0].name.value].items,
          );
        })
        .catch((error) => {
          this.handleMutationError(error);
        })
        .finally(() => {
          this.handleLoading(false);
        });
    },
  },
};

==> aleksis_core-4.0.1-py3-none-any.whl: aleksis/core/frontend/mixins/mutateMixin.js <==
import loadingMixin from "./loadingMixin.js";
import mutatePropsMixin from "./mutatePropsMixin";

/**
 * This mixin provides generic graphQL mutation handling.
 */
export default {
  mixins: [loadingMixin, mutatePropsMixin],
  // update & save come from DialogObjectForm
  // save could be success as well but keeping it backwards compatible
  // for now
  emits: ["update", "save"],
  computed: {
    // Expand the affectedQuery
    expandedQuery() {
      if (!this.affectedQuery) {
        return false;
      }
      return {
        ...this.affectedQuery.options,
        variables: JSON.parse(this.affectedQuery.previousVariablesJson),
      };
    },
  },
  methods: {
    /**
     * Do a graphQL mutation with variables
     *
     * Provide updateStore to update the cached data for affectedQuery with
     * the incoming data.
     *
     * @param {Object} mutation
     * @param {Object} variables
     * @param {Function} updateStore
     * @param {Object} additionalArgs additional arguments passed to apollo mutate function options
     */
    mutate(
      mutation,
      variables,
      updateStore = (cached, incoming) => {},
      additionalArgs = {},
    ) {
      this.handleLoading(true);

      if (this.customUpdate) {
        updateStore = this.customUpdate;
      }

      this.$apollo
        .mutate({
          mutation: mutation,
          variables: variables,
          update: (store, data) => {
            // TODO: Is data transformed properly?
            // Current implemented for create | patch
            // What does it return for delete?
            data = data.data[mutation.definitions[0].name.value].items;

            // Update cached data
            if (this.expandedQuery) {
              // Read the data from cache for query
              const cachedQuery = store.readQuery(this.expandedQuery);
              if (cachedQuery) {
                // Update the store
                this.setKeysRecursive(
                  this.gqlDataKey,
                  cachedQuery,
                  updateStore(
                    this.getKeysRecursive(this.gqlDataKey, cachedQuery),
                    data,
                  ),
                );
                // Write data back to the cache
                store.writeQuery({ ...this.expandedQuery, data: cachedQuery });
              }
            }

            /**
             * Emits the store and data when graphQL updates
             * Use this to update the cached query if  affectedQuery or
             * updateStore was not provided
             *
             * @property {object} store
             * @property {object} updated object
             */
            this.$emit("update", store, data);
          },
          ...additionalArgs,
        })
        .then((data) => {
          /**
           * Emits the items of a successful graphQL mutation
           * If affectedQuery was provided the items are already updated in the cache.
           *
           * @property {object} data
           */
          this.$emit(
            "save",
            data.data[mutation.definitions[0].name.value].items,
          );
        })
        .catch((error) => {
          this.handleMutationError(error);
        })
        .finally(() => {
          this.handleLoading(false);
        });
    },
  },
};
